from django.forms import ModelForm
from django import forms
from models import *

class PhotoForm(ModelForm):
	class Meta:
		model = Photo
		exclude = {'approved',}
		widgets = {
            'message': forms.Textarea(attrs={'cols': 80, 'rows': 20}),
        }
		


from django.conf.urls import patterns, include, url
from django.contrib import admin
from django.conf import settings
admin.autodiscover()

urlpatterns = patterns('',
    url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
    url(r'^admin/', include(admin.site.urls)),
)

urlpatterns += patterns('paintedword.views',
    (r'^(?P<slug>[\w-]+)/$', 'render_photo_campaign'),
    (r'^(?P<slug>[\w-]+)/submit$', 'submit')
)

if settings.DEBUG:
    # quick fix for the fact that my media files are being served by static URL
    urlpatterns += patterns('',
        (r'^media/(?P<path>.*)$', 'django.views.static.serve', {
        'document_root': settings.MEDIA_ROOT}))


from distutils.core import setup
from setuptools import find_packages

setup(
    name='painted-word',
    version='0.0.1',
    author='Mike Vattuone',
    author_email='mvattuone@gmail.com',
    url='https://github.com/mvattuone/painted-word',
    license='LICENSE.txt',
    description='A set of helpers for building an image based campaign.  Plays nicely with the Actionkit CRM.',
    long_description=open('README.txt').read(),
    install_requires=[
        "Django>=1.4.5",
    ],
    packages=find_packages(),
    include_package_data=True,
)


from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from django.views.decorators.csrf import csrf_exempt
from django.http import HttpResponse,HttpResponseBadRequest,HttpResponseServerError
from django.core.files.base import ContentFile
from django.conf import settings
from django.shortcuts import render
import json

import re
from django.core.files.base import ContentFile
import tempfile

from ak_support.views import ak_connect

from models import *
from forms import *


def render_photo_campaign(request,slug):
    context = {}

    campaign = get_object_or_404(PhotoCampaign,slug=slug)
    form = PhotoForm()
    photoupload = PhotoForm(request.POST or None)

    if form.is_valid():
        new_photo = form.save()

    response_data = {
        'form': form,
    }

    form = PhotoForm(request.POST or None, request.FILES or None)

    if form.is_valid():
        new_upload = form.save()
    else:
        print form.errors

    context = {
        'photos': Photo.objects.filter(campaign=campaign,approved=True),
        'form': form,
        'logo':campaign.logo,
        'title':campaign.title,
        'description':campaign.description,
        'page_name':campaign.ak_page_name,
        'example_photo': campaign.render_example_photo(),
        'default_message': campaign.default_message,
        'campaign_link': campaign.get_absolute_url(),
    }

    return render(request, "paintedword.html", dictionary=context)
        
@csrf_exempt
def submit(request,slug):
    required_fields = ['name','captioned_photo']
    for f in required_fields:
        if request.POST.get(f) == "":
            resp = {'message':'%s is required' % f,
                    'field':f}
            return HttpResponseBadRequest(json.dumps(resp),mimetype="application/json")

    #decode the dataurl
    dataurl = request.POST['captioned_photo']
    encoded_photo = re.search(r'base64,(.*)', dataurl).group(1)
    decoded_photo = encoded_photo.decode('base64')

    #save it to a ContentFile
    captioned_content_file = ContentFile(decoded_photo)
    captioned_file_name = "test_upload.png"

	#create the django photo object
    try:
        campaign = PhotoCampaign.objects.get(slug=slug)
    except PhotoCampaign.DoesNotExist:
        resp = {'message':'no such campaign %s' % slug}
        return HttpResponseServerError(json.dumps(resp),mimetype="application/json")

    new_photo = Photo.objects.create(name=request.POST.get('name'),
                                     campaign=campaign,)
    try:
        new_photo.captioned_photo.save(captioned_file_name,captioned_content_file)
        new_photo.save()
        resp = {'message':'success'}
    except Exception:
        resp = {"message":"error"}

    return HttpResponse(json.dumps(resp),mimetype="application/json")



import os,sys
from os.path import join
PROJECT_PATH = os.path.abspath(os.path.split(__file__)[0])
DEBUG = True
TEMPLATE_DEBUG = DEBUG


ADMINS = (
    # ('Mike Vattuone', 'your_email@example.com'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
        'NAME': 'dev.db',                      # Or path to database file if using sqlite3.
        'USER': '',                      # Not used with sqlite3.
        'PASSWORD': '',                  # Not used with sqlite3.
        'HOST': '',                      # Set to empty string for localhost. Not used with sqlite3.
        'PORT': '',                      # Set to empty string for default. Not used with sqlite3.
    }
}

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = 'America/Chicago'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en-us'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale.
USE_L10N = True

# If you set this to False, Django will not use timezone-aware datetimes.
USE_TZ = True

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = os.path.join(PROJECT_PATH,'media')

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = '/media/'

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = os.path.join(PROJECT_PATH,'..','static')

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# Additional locations of static files
STATICFILES_DIRS = (

)



# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'django.contrib.staticfiles.finders.DefaultStorageFinder',
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = '#&amp;os8a9-$%05$h&amp;&amp;(d47_e5h)52kzcv404031zrjlh#u=up$-p'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
    'django.template.loaders.eggs.Loader',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

ROOT_URLCONF = 'paintedword.urls'

# Python dotted path to the WSGI application used by Django's runserver.
WSGI_APPLICATION = 'paintedword.wsgi.application'

TEMPLATE_DIRS = (
    os.path.join(PROJECT_PATH,'templates')

)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
    'django.contrib.admindocs',    
    'paintedword',
)

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    }
}





from models import *
from django.contrib import admin

from django import forms 

#override CharField to show a TextArea instead.  We want to cut message length so people can't type too much onto the canvas
#but a single text input is obnoxious.

class PhotoMessageModelForm(forms.ModelForm):
	message = forms.CharField(widget=forms.Textarea)
	class Meta:
		model = Photo

class PhotoCampaignAdmin(admin.ModelAdmin):
	prepopulated_fields = {"slug": ("title",)}
	list_display = ['title','description']

class PhotoAdmin(admin.ModelAdmin):
	form = PhotoMessageModelForm
	list_filter = ('approved','campaign')
	list_display = ['final_photo','approved']
	list_editable = ['approved',]

admin.site.register(PhotoCampaign, PhotoCampaignAdmin)
admin.site.register(Photo,PhotoAdmin)
